pub struct PushQuote {Show 14 fields
pub symbol: String,
pub sequence: i64,
pub last_done: String,
pub open: String,
pub high: String,
pub low: String,
pub timestamp: i64,
pub volume: i64,
pub turnover: String,
pub trade_status: i32,
pub trade_session: i32,
pub current_volume: i64,
pub current_turnover: String,
pub tag: i32,
}Fields
symbol: Stringsequence: i64last_done: Stringopen: Stringhigh: Stringlow: Stringtimestamp: i64volume: i64turnover: Stringtrade_status: i32trade_session: i32current_volume: i64current_turnover: Stringtag: i32Implementations
Sourceimpl PushQuote
impl PushQuote
Sourcepub fn trade_status(&self) -> TradeStatus
pub fn trade_status(&self) -> TradeStatus
Returns the enum value of trade_status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_trade_status(&mut self, value: TradeStatus)
pub fn set_trade_status(&mut self, value: TradeStatus)
Sets trade_status to the provided enum value.
Sourcepub fn trade_session(&self) -> TradeSession
pub fn trade_session(&self) -> TradeSession
Returns the enum value of trade_session, or the default if the field is set to an invalid enum value.
Sourcepub fn set_trade_session(&mut self, value: TradeSession)
pub fn set_trade_session(&mut self, value: TradeSession)
Sets trade_session to the provided enum value.
Sourcepub fn tag(&self) -> PushQuoteTag
pub fn tag(&self) -> PushQuoteTag
Returns the enum value of tag, or the default if the field is set to an invalid enum value.
Sourcepub fn set_tag(&mut self, value: PushQuoteTag)
pub fn set_tag(&mut self, value: PushQuoteTag)
Sets tag to the provided enum value.