#[repr(i32)]pub enum Command {
Show 32 variants
UnknownCommand = 0,
HeartBeat = 1,
Auth = 2,
Reconnect = 3,
QueryUserQuoteProfile = 4,
Subscription = 5,
Subscribe = 6,
Unsubscribe = 7,
QueryMarketTradePeriod = 8,
QueryMarketTradeDay = 9,
QuerySecurityStaticInfo = 10,
QuerySecurityQuote = 11,
QueryOptionQuote = 12,
QueryWarrantQuote = 13,
QueryDepth = 14,
QueryBrokers = 15,
QueryParticipantBrokerIds = 16,
QueryTrade = 17,
QueryIntraday = 18,
QueryCandlestick = 19,
QueryOptionChainDate = 20,
QueryOptionChainDateStrikeInfo = 21,
QueryWarrantIssuerInfo = 22,
QueryWarrantFilterList = 23,
QueryCapitalFlowIntraday = 24,
QueryCapitalFlowDistribution = 25,
QuerySecurityCalcIndex = 26,
QueryHistoryCandlestick = 27,
PushQuoteData = 101,
PushDepthData = 102,
PushBrokersData = 103,
PushTradeData = 104,
}Expand description
协议指令定义
Variants
UnknownCommand = 0
HeartBeat = 1
心跳
Auth = 2
鉴权
Reconnect = 3
重新连接
QueryUserQuoteProfile = 4
查询用户行情信息
Subscription = 5
查询连接的已订阅数据
Subscribe = 6
订阅行情数据
Unsubscribe = 7
取消订阅行情数据
QueryMarketTradePeriod = 8
查询各市场的当日交易时段
QueryMarketTradeDay = 9
查询交易日
QuerySecurityStaticInfo = 10
查询标的基础信息
QuerySecurityQuote = 11
查询标的行情(所有标的通用行情)
QueryOptionQuote = 12
查询期权行情(仅支持期权)
QueryWarrantQuote = 13
查询轮证行情(仅支持轮证)
QueryDepth = 14
查询盘口
QueryBrokers = 15
查询经纪队列
QueryParticipantBrokerIds = 16
查询券商经纪席位
QueryTrade = 17
查询成交明细
QueryIntraday = 18
查询当日分时
QueryCandlestick = 19
查询k线
QueryOptionChainDate = 20
查询标的期权链日期列表
QueryOptionChainDateStrikeInfo = 21
查询标的期权链某日的行权价信息
QueryWarrantIssuerInfo = 22
查询轮证发行商对应Id
QueryWarrantFilterList = 23
查询轮证筛选列表
QueryCapitalFlowIntraday = 24
查询标的的资金流分时
QueryCapitalFlowDistribution = 25
查询标的资金流大小单
QuerySecurityCalcIndex = 26
查询标的指标数据
QueryHistoryCandlestick = 27
查询标的历史 k 线
PushQuoteData = 101
推送行情
PushDepthData = 102
推送盘口
PushBrokersData = 103
推送经纪队列
PushTradeData = 104
推送成交明细
Implementations
Sourceimpl Command
impl Command
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.